@@ -71,52 +71,56 @@ class MotorcycleModelWorkbook:
 
         for sheetname in [key for key in workbook.sheetnames
                           if key in SHEETNAMES_RELATIONSHIPS]:
-            if Sheetnames.ENGINE == SHEETNAMES_RELATIONSHIPS[sheetname]:
-                engine_sheet: EngineSheet = EngineSheet(worksheet=workbook[sheetname])
-                engine_sections: List[EngineSection] = engine_sheet.engine_sections
+            try:
+                if Sheetnames.ENGINE == SHEETNAMES_RELATIONSHIPS[sheetname]:
+                    engine_sheet: EngineSheet = EngineSheet(worksheet=workbook[sheetname])
+                    engine_sections: List[EngineSection] = engine_sheet.engine_sections
 
-            elif Sheetnames.GENERIC_REPLACEMENTS == SHEETNAMES_RELATIONSHIPS[sheetname]:
-                generic_replacements = \
-                    GenericReplacementsSheet(worksheet=workbook[sheetname]).get_generic_replacements()
+                elif Sheetnames.GENERIC_REPLACEMENTS == SHEETNAMES_RELATIONSHIPS[sheetname]:
+                    generic_replacements = \
+                        GenericReplacementsSheet(worksheet=workbook[sheetname]).get_generic_replacements()
 
-            elif Sheetnames.ELECTRONIC == SHEETNAMES_RELATIONSHIPS[sheetname]:
-                electronic_elements = \
-                    ElectronicSheet(worksheet=workbook[sheetname]).get_electronic_elements()
+                elif Sheetnames.ELECTRONIC == SHEETNAMES_RELATIONSHIPS[sheetname]:
+                    electronic_elements = \
+                        ElectronicSheet(worksheet=workbook[sheetname]).get_electronic_elements()
 
-            elif Sheetnames.TIGHTENING_TORQUES == SHEETNAMES_RELATIONSHIPS[sheetname]:
-                tightening_specifications = \
-                    TighteningSpecificationsSheet(worksheet=workbook[sheetname]).get_specification_elements()
+                elif Sheetnames.TIGHTENING_TORQUES == SHEETNAMES_RELATIONSHIPS[sheetname]:
+                    tightening_specifications = \
+                        TighteningSpecificationsSheet(worksheet=workbook[sheetname]).get_specification_elements()
 
-            elif Sheetnames.FRAME == SHEETNAMES_RELATIONSHIPS[sheetname]:
-                frame_elements = FrameSheet(worksheet=workbook[sheetname]).frame_elements
+                elif Sheetnames.FRAME == SHEETNAMES_RELATIONSHIPS[sheetname]:
+                    frame_elements = FrameSheet(worksheet=workbook[sheetname]).frame_elements
 
-            elif Sheetnames.POWER_SUPPLY == SHEETNAMES_RELATIONSHIPS[sheetname]:
-                power_supply_components = PowerSupplySheet(worksheet=workbook[sheetname]).components
+                elif Sheetnames.POWER_SUPPLY == SHEETNAMES_RELATIONSHIPS[sheetname]:
+                    power_supply_components = PowerSupplySheet(worksheet=workbook[sheetname]).components
 
-            elif Sheetnames.DISTRIBUTION == SHEETNAMES_RELATIONSHIPS[sheetname]:
-                distribution_sheet: DistributionSheet = DistributionSheet(worksheet=workbook[sheetname])
+                elif Sheetnames.DISTRIBUTION == SHEETNAMES_RELATIONSHIPS[sheetname]:
+                    distribution_sheet: DistributionSheet = DistributionSheet(worksheet=workbook[sheetname])
 
-                distribution = distribution_sheet.distribution_data
-                self.distribution_images = distribution_sheet.distribution_images
+                    distribution = distribution_sheet.distribution_data
+                    self.distribution_images = distribution_sheet.distribution_images
 
-            elif Sheetnames.AUTODIAGNOSIS == SHEETNAMES_RELATIONSHIPS[sheetname]:
-                autodiagnosis = AutodiagnosisSheet(worksheet=workbook[sheetname]).autodiagnosis
+                elif Sheetnames.AUTODIAGNOSIS == SHEETNAMES_RELATIONSHIPS[sheetname]:
+                    autodiagnosis = AutodiagnosisSheet(worksheet=workbook[sheetname]).autodiagnosis
 
-            elif Sheetnames.ABS == SHEETNAMES_RELATIONSHIPS[sheetname]:
-                abs_data = AbsSheet(worksheet=workbook[sheetname]).abs_data
+                elif Sheetnames.ABS == SHEETNAMES_RELATIONSHIPS[sheetname]:
+                    abs_data = AbsSheet(worksheet=workbook[sheetname]).abs_data
 
-            elif Sheetnames.SMART_KEY == SHEETNAMES_RELATIONSHIPS[sheetname]:
-                smart_key_sheet = SmartKeySheet(worksheet=workbook[sheetname])
-                smart_key_data = smart_key_sheet.smart_key_data
-                self.smart_key_images = smart_key_sheet.smart_key_images
+                elif Sheetnames.SMART_KEY == SHEETNAMES_RELATIONSHIPS[sheetname]:
+                    smart_key_sheet = SmartKeySheet(worksheet=workbook[sheetname])
+                    smart_key_data = smart_key_sheet.smart_key_data
+                    self.smart_key_images = smart_key_sheet.smart_key_images
 
-            elif Sheetnames.COMPONENTS == SHEETNAMES_RELATIONSHIPS[sheetname]:
-                components_sheet = ComponentsSheet(worksheet=workbook[sheetname])
-                components_data = components_sheet.components_data
-                self.components_image = components_sheet.components_image
+                elif Sheetnames.COMPONENTS == SHEETNAMES_RELATIONSHIPS[sheetname]:
+                    components_sheet = ComponentsSheet(worksheet=workbook[sheetname])
+                    components_data = components_sheet.components_data
+                    self.components_image = components_sheet.components_image
 
-            elif Sheetnames.HISS_INMOBILIZER == SHEETNAMES_RELATIONSHIPS[sheetname]:
-                hiss_immobilizer_data = HissImmobilizerSheet(worksheet=workbook[sheetname]).hiss_immobilizer_data
+                elif Sheetnames.HISS_INMOBILIZER == SHEETNAMES_RELATIONSHIPS[sheetname]:
+                    hiss_immobilizer_data = HissImmobilizerSheet(worksheet=workbook[sheetname]).hiss_immobilizer_data
+
+            except Exception as error:
+                print(error)
 
         self.motorcycle_model = XlsxMotorcycleModel(
             model_name=model_name,
